job "git" {
  schedule = "@daily"

  config {
    repo = "s3://backups-minio.agnosticfront.thefij:8443/nomad/gitea"
    passphrase = env("BACKUP_PASSPHRASE")

    options {
      InsecureTls = true
    }
  }

  task "Create local gitea dir" {
    pre_script {
      on_backup = "mkdir -p /local/gitea"
    }
  }

  task "Backup database" {
    mysql "Backup database" {
      hostname       = env("MYSQL_HOST")
      port           = env("MYSQL_PORT")
      database       = "gitea"
      username       = env("MYSQL_USER")
      password       = env("MYSQL_PASSWORD")
      no_tablespaces = true
      dump_to        = "/local/gitea/dump.sql"
    }
  }

  backup {
    paths = [
      "/local/gitea",
      "/data/nas-container/gitea",
    ]

    backup_opts {
      Host = "nomad"
    }

    restore_opts {
      Host = ["nomad"]
      # Because path is absolute
      Target = "/"
    }
  }

  forget {
    KeepLast = 2
    KeepHourly = 24
    KeepDaily = 30
    KeepWeekly = 8
    KeepMonthly = 6
    KeepYearly = 2
    Prune = true
  }
}
